#!/usr/bin/env node
'use strict';

var fs = require('fs');
var path = require('path');
var execSync = require("child_process").execSync;

var _require = require('../lib/utils'),
    log = _require.log;

var workspaceRoot = process.cwd();
var branchName = execSync('git symbolic-ref --short -q HEAD').toString().trim();

function getConfig() {
  // 默认值
  var defaultPattern = "^20\\\\d{2}(10|11|12|(0\\\\d))(((0|1)\\\\d)|(30|31))-\\S";
  var defaultNote = "分支名字格式无效,有效的格式 日期+描述,如 20180512-add-dialog";

  var packageFolder = path.resolve(workspaceRoot, 'package.json');
  if (!packageFolder) {
    log('No package.json folder found', error);
    process.exit(-1);
  }
  var packageJson = JSON.parse(fs.readFileSync(packageFolder, 'utf8'));

  // 设置默认值
  var pattern = void 0;
  var helpMessage = void 0;
  var ignorePattern = void 0;
  var justWarnOnfail = false;
  if (!packageJson.config || !packageJson.config['validate-git-branch'] || !packageJson.config['validate-git-branch']['pattern']) {
    pattern = defaultPattern;
    helpMessage = defaultNote;
  } else {
    var config = packageJson.config['validate-git-branch'];
    pattern = config.pattern;
    helpMessage = config.helpMessage || "分支名字格式无效";
  }

  if (packageJson.config && packageJson.config['validate-git-branch'] && packageJson.config['validate-git-branch']['ignorePattern']) {
    ignorePattern = packageJson.config['validate-git-branch']['ignorePattern'];
  }

  if (packageJson.config && packageJson.config['validate-git-branch'] && packageJson.config['validate-git-branch']['justWarnOnfail']) {
    justWarnOnfail = packageJson.config['validate-git-branch']['justWarnOnfail'];
  }

  return {
    pattern: pattern, helpMessage: helpMessage, ignorePattern: ignorePattern, justWarnOnfail: justWarnOnfail
  };
}

function excute() {
  var _getConfig = getConfig(),
      pattern = _getConfig.pattern,
      helpMessage = _getConfig.helpMessage,
      ignorePattern = _getConfig.ignorePattern,
      justWarnOnfail = _getConfig.justWarnOnfail;
  // 校验


  if (ignorePattern && new RegExp(ignorePattern).test(branchName)) {
    log('符合分支名称校验的例外规则', 'info');
    return;
  }
  var targetPattern = new RegExp(pattern);
  if (!targetPattern.test(branchName)) {

    if (!justWarnOnfail) {
      log(helpMessage, 'error');
      process.exit(-1);
    }
    log(helpMessage, 'warn');
    return;
  }
  log('分支名称校验通过', 'info');
}

excute();